@@ -4,13 +4,11 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef breezebaseengine_h
-#define breezebaseengine_h
+#pragma once
 
 #include "breeze.h"
 
 #include <QObject>
-#include <QSet>
 
 namespace Breeze
 {
@@ -56,15 +54,6 @@ public:
     //* unregister widget
     virtual bool unregisterWidget(QObject *object) = 0;
 
-    //* list of widgets
-    using WidgetList = QSet<QWidget *>;
-
-    //* returns registered widgets
-    virtual WidgetList registeredWidgets() const
-    {
-        return WidgetList();
-    }
-
 private:
     //* engine enability
     bool _enabled = true;
@@ -74,5 +63,3 @@ private:
 };
 
 }
-
-#endif
